function [t_dz L_ex_8h]=Alternative_2(p2,Fs,doplot,exponent)
% Hearing Model, alternative 2.
%   This model uses IROS(n)=(67/R)*p^2.
%   Damaging limits are 8 hours in 85 dB for both the linear and the 
%   squared stress summation.
%
%   [t_dz L_ex_8h]=ALTERNATIVE_2(p2,Fs,doplot,exponent)
%   Output: 
%       t_dz - Time to reach damage, 
%       L_ex_8h - 8 hours equivalent SPL (according to ISO, calculated 
%       from the signals total energy).
%   Input: 
%       p2 [Pa^2] - squared pressure 
%       Fs [sample/min] (>=1) - number of samples per minute 
%       doplot (0 or 1) - 1=plot, 0=no plot
%       exponent (1, 2 or 3) - exponent used in the stress summation. 3 is
%       the divided stress summation using 1st order for SPL < 85 dB and 
%       2nd order for SPL >= 85 dB
%
%   The function vline.m and sublabel.m must be present to plot figure.
%
%   Made by: Sverre Aas & Tron Vedul Tronstad, 2007.

%%%%%%%%%%%%%%%%%%%%%% Checking if inputs are ok %%%%%%%%%%%%%%%%%%%%%%%%%
if ~(exponent==1 | exponent==2 | exponent==3)
    error('Input "exponent" has to be 1, 2 or 3.');
end
if Fs<1
    error('Input "Fs" has to be larger than 1.');
end
if ~(doplot==1 | doplot==0)
    error('Input "doplot" has to be 0 or 1.');
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%% Creating different constants and vectors needed %%%%%%%%%%%%%%%%
delta_t=1/Fs;
t=0:delta_t:length(p2)*delta_t;
t_dz=0;t_eeh=0;
n0=1;
p0=20e-6;
check=0;check_Ea=0;
skade=0;teller=0;
Vg=0.08476;             % Production of antioxidants. Adjusted to 
                        % "take care" of ROS production at 65 dB.
a=67;
R=1000;C=126e-3;
RC=R*C;                 % Timeconstant 2.1h = 126 min

%%%%%%%%%%%%%% Damaging limits used in the stress summation %%%%%%%%%%%%%%
S1=2987;        % 85 dB 8 h. Limit for the linear summation.
S2=20750;       % 85 dB 8 h. Limit for the squared summation.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Sets the initial values in the for-loop and runs it %%%%%%%%%%%
Vc(1)=Vg;       % <-- Assumes that the ear is completely recovered when
                % the exposure starts.
Ea(1)=p2(1)*delta_t*60;
for n=2:length(p2)
    if p2(n)~=p2(n-1);n0=n-1;end % <-- Checks if there has been a change 
                                 % in pressure. Used in Vc(n).
%%%%%%%%%%%%%%%%%%% Calculating the energy %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Ea(n)=Ea(n-1)+[p2(n)*delta_t*60];
%%%%%%%%%%%%%%%%%%% Setting the ROS production %%%%%%%%%%%%%%%%%%%%%%%%%%%
    IROS(n)=a.*p2(n)/R;
%%%%%%%%%%%%%%%%%%% Calculating the concentration of ROS %%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%% using the RC equation                %%%%%%%%%%%%%%%%%
    Vc(n)=(Vg-IROS(n)*R)+[Vc(n0)-(Vg-IROS(n)*R)]*exp(-(n-n0)*delta_t/RC);
%%%%%%% Estimating if damage migth occur                             %%%%%
%%%%%%% Uses either 1st, 2nd or a combined order exponent in the sum %%%%%
    if Vc(n)<0
        teller=teller+1;
        if exponent==1
            skade=skade-Vc(n)*delta_t;
        elseif exponent==2
            skade=skade+[Vc(n)^2]*delta_t;   
        elseif exponent==3
            if 10*log10(p2(n)/p0^2)>=85
                skade=skade+[Vc(n)^2]*delta_t;
            else
                skade=skade-Vc(n)*delta_t;
            end
        end
    else
        skade=0;            % <-- If concentration of damaging compound 
                            % gets positive (more antioxidants than ROS), 
                            % the damage summation resets.
    end
%%%%%%%%%%%%%%%%%%%%% Checking if damaging limit is reached %%%%%%%%%%%%%%
    if  exponent==1 & skade>S1 & check==0;
        check=1;
        t_dz=n*delta_t;
    elseif exponent==2 & skade>S2 & check==0
        check=1;
        t_dz=n*delta_t;
    elseif exponent==3 & check==0;
        if (10*log10(p2(n)/p0^2)>=85 & skade>S2) | (10*log10(p2(n)/p0^2)<85 & skade>S1)
            check=1;
            t_dz=n*delta_t;
        end
    end
%%%% Checking if the energy has dangerous level according to ISO 1999 %%%%
    if Ea(n)>3.64e3 & check_Ea==0;t_eeh=n*delta_t;check_Ea=1;end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%% The code below plots the result %%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%% Optimized for printing          %%%%%%%%%%%%%%%%%%%%%%%%%%
if doplot
    figure
    haxes(1)=subplot(211);[ax1,h0(1),h0(2)]=plotyy(t(1:length(p2)), ...
            -Vc,t(1:length(p2)),10*log10(p2/p0^2),'semilogx');
    pos11=get(ax1(1),'position');set(ax1(1),'Position', ...
          [pos11(1) 0.59 pos11(3) 0.32]);
    pos12=get(ax1(2),'position');set(ax1(2),'Position', ...
          [pos12(1) 0.59 pos12(3) 0.32]);
    h(1)=xlabel('Log time [min]');h(2)=ylabel('TTS [dB]');
    axis([delta_t length(p2)*delta_t 0 100]);
    set(ax1(1),'YTick',0:20:100,'YMinorTick','on');
    axes(ax1(2));h(3)=ylabel('Exposure SPL [dBA]');
    axis([delta_t length(p2)*delta_t 0 130]);%axis ij;
    set(ax1(2),'YTick',0:20:130,'YMinorTick','on','XAxisLocation', ...
        'Top','XTick',[1:9 60:60:540 60*24:60*24:7*60*24],'XTickLabel', ...
        [1:9 1:9 1:7]);
    line(1:9,130,'Color','k','Marker','+');
    line(60:60:9*60,130,'Color','k','Marker','+');
    line(60*24:60*24:7*60*24,130,'Color','k','Marker','+');
    if length(p2)*delta_t>7
        h(4)=text(3,150,'Minutes','Color','k');
    end
    if length(p2)*delta_t>60*4
        h(5)=text(3*60,150,'Hours','Color','k');
    end
    if length(p2)*delta_t>60*24*3
        h(6)=text(2*60*24,150,'Days','Color','k');
    end
    if t_dz~=0;vline(t_dz,'r:','DZ',7);end
    set(h,'FontSize',12)
    if t_eeh~=0;vline(t_eeh,'c:','EEH-limit',19);end

    haxes(2)=subplot(212);[ax2,h0(3),h0(4)]=plotyy(t(1:length(p2)), ...
             -Vc,t(1:length(p2)),10*log10(p2/p0^2),'plot');
    pos21=get(ax2(1),'position');set(ax2(1),'Position', ...
          [pos21(1) 0.09 pos21(3) 0.32]);
    pos22=get(ax2(2),'position');set(ax2(2),'Position', ...
          [pos22(1) 0.09 pos22(3) 0.32]);
    hh(1)=xlabel('Lin time [min]');hh(2)=ylabel('TTS [dB]');
    axis([1 length(p2)*delta_t 0 100]);
    set(ax2(1),'YTick',0:20:100,'YMinorTick','on');
    axes(ax2(2));hh(3)=ylabel('Exposure SPL [dBA]');
    axis([1 length(p2)*delta_t 0 130]);%axis ij;
    if length(p2)*delta_t<60*24*3
        set(ax2(2),'YTick',0:20:130,'XAxisLocation','Top','XTick', ...
            [60:60:540 60*24:60*24:7*60*24],'XTickLabel',[1:9 1:7]);
        line(60:60:9*60,130,'Color','k','Marker','+')
    else;set(ax2(2),'YTick',0:20:130,'YMinorTick','on','XAxisLocation', ...
            'Top','XTick',[60*24:60*24:7*60*24],'XTickLabel',[1:7]);
    end    
    if length(p2)*delta_t>60*3 & length(p2)*delta_t<60*24*3
        text(3*60,150,'Hours','Color','k','FontSize',12);
    end
    if length(p2)*delta_t>60*24*2.3
        text(2*60*24,150,'Days','Color','k','FontSize',12);
    end        
    line(60*24:60*24:7*60*24,130,'Color','k','Marker','+');
    if t_dz~=0;vline(t_dz,'r:','DZ',7);end
    if t_eeh~=0;vline(t_eeh,'c:','EEH-limit',19);end
    htext=sublabel(haxes);
    set(hh,'FontSize',12)
    set(h0,'LineWidth',0.9)
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if t_dz==0;
    disp('The exposure is not dangerous according to the model.')
end
Ea_tot=Ea(end);
L_ex_8h=round(10*log10(Ea_tot/1.15e-5));
return